#!/usr/bin/env python3

# Copyright (C) 2013 LiuLang <gsushzhsosgsu@gmail.com>

# Use of this source code is governed by GPLv3 license that can be found
# in the LICENSE file.

from gi.repository import Gdk
from gi.repository import GdkPixbuf
from gi.repository import Gtk


class TitleBar(Gtk.EventBox):
    def __init__(self, parent):
        self.parent = parent

        super().__init__()
        self.add_events(
                Gdk.EventType.BUTTON_PRESS |
                Gdk.EventType.BUTTON_RELEASE |
                Gdk.EventType.MOTION_NOTIFY)
        self.connect('button-press-event', self.on_mouse_pressed)
        self.connect('button-release-event', self.on_mouse_released)
        self.connect('motion-notify-event', self.on_mouse_moved)

        img_path = 'img/bg.jpg'
        titlebar_pix = GdkPixbuf.Pixbuf.new_from_file_at_size(
                img_path, parent.get_size_request()[0], 200)
        img = Gtk.Image()
        img.set_from_pixbuf(titlebar_pix)
        self.add(img)

        self.mouse_pressed = False

        screen = parent.get_screen()
        self.gdk_window = screen.get_root_window()

    def on_mouse_pressed(self, eventbox, event):
        self.start_x, self.start_y = event.x, event.y
        self.mouse_pressed = True
        cursor = Gdk.Cursor(Gdk.CursorType.FLEUR)
        self.gdk_window.set_cursor(cursor)

    def on_mouse_released(self, eventbox, event):
        self.mouse_pressed = False
        cursor = Gdk.Cursor(Gdk.CursorType.ARROW)
        self.gdk_window.set_cursor(cursor)

    def on_mouse_moved(self, eventbox, event):
        if not self.mouse_pressed:
            return
        x = int(event.x_root - self.start_x)
        y = int(event.y_root - self.start_y)
        self.parent.move(x, y)


class App(Gtk.Window):
    def __init__(self):
        super().__init__()
        self.set_decorated(False)
        # Is this a really good idea to stop user from resizing window?
        self.set_size_request(850, 600)
        self.set_resizable(False)
        self.set_position(Gtk.WindowPosition.CENTER)
        self.connect('delete-event', self.on_app_exit)

        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
        self.add(vbox)

        titlebar = TitleBar(self)
        vbox.pack_start(titlebar, False, False, 0)


    def run(self):
        self.show_all()
        Gtk.main()

    def on_app_exit(self, *args):
        # Do something, like saving a file, or close a connection.
        Gtk.main_quit()


if __name__ == '__main__':
    app = App()
    app.run()
